summaryrefslogtreecommitdiffstats
path: root/kjsembed/qtbindings/qcanvaspixmap_imp.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kjsembed/qtbindings/qcanvaspixmap_imp.cpp')
-rw-r--r--kjsembed/qtbindings/qcanvaspixmap_imp.cpp54
1 files changed, 27 insertions, 27 deletions
diff --git a/kjsembed/qtbindings/qcanvaspixmap_imp.cpp b/kjsembed/qtbindings/qcanvaspixmap_imp.cpp
index 846f90fc..505cdb1f 100644
--- a/kjsembed/qtbindings/qcanvaspixmap_imp.cpp
+++ b/kjsembed/qtbindings/qcanvaspixmap_imp.cpp
@@ -1,12 +1,12 @@
-#include <qcstring.h>
-#include <qimage.h>
-#include <qpainter.h>
-#include <qpalette.h>
-#include <qpixmap.h>
-#include <qfont.h>
+#include <tqcstring.h>
+#include <tqimage.h>
+#include <tqpainter.h>
+#include <tqpalette.h>
+#include <tqpixmap.h>
+#include <tqfont.h>
#include <kjs/object.h>
@@ -15,7 +15,7 @@
#include <kjsembed/jsopaqueproxy.h>
#include <kjsembed/jsbinding.h>
-#include <qcanvas.h>
+#include <tqcanvas.h>
#include "qcanvaspixmap_imp.h"
/**
@@ -43,7 +43,7 @@ void QCanvasPixmapImp::addStaticBindings( KJS::ExecState *exec, KJS::Object &obj
};
int idx = 0;
- QCString lastName;
+ TQCString lastName;
while( methods[idx].name ) {
if ( lastName != methods[idx].name ) {
@@ -71,7 +71,7 @@ void QCanvasPixmapImp::addBindings( KJS::ExecState *exec, KJS::Object &object )
};
int idx = 0;
- QCString lastName;
+ TQCString lastName;
while( methods[idx].name ) {
if ( lastName != methods[idx].name ) {
@@ -84,25 +84,25 @@ void QCanvasPixmapImp::addBindings( KJS::ExecState *exec, KJS::Object &object )
}
/**
* Extract a QCanvasPixmap pointer from an Object.
*/
-QCanvasPixmap *QCanvasPixmapImp::toQCanvasPixmap( KJS::Object &self )
+TQCanvasPixmap *QCanvasPixmapImp::toQCanvasPixmap( KJS::Object &self )
{
JSObjectProxy *ob = JSProxy::toObjectProxy( self.imp() );
if ( ob ) {
- QObject *obj = ob->object();
+ TQObject *obj = ob->object();
if ( obj )
- return dynamic_cast<QCanvasPixmap *>( obj );
+ return dynamic_cast<TQCanvasPixmap *>( obj );
}
JSOpaqueProxy *op = JSProxy::toOpaqueProxy( self.imp() );
if ( !op )
return 0;
- if ( op->typeName() != "QCanvasPixmap" )
+ if ( op->typeName() != "TQCanvasPixmap" )
return 0;
- return op->toNative<QCanvasPixmap>();
+ return op->toNative<TQCanvasPixmap>();
}
/**
@@ -128,7 +128,7 @@ KJS::Object QCanvasPixmapImp::construct( KJS::ExecState *exec, const KJS::List &
break;
}
- QString msg = i18n("QCanvasPixmapCons has no constructor with id '%1'.").arg(id);
+ TQString msg = i18n("QCanvasPixmapCons has no constructor with id '%1'.").arg(id);
return throwError(exec, msg,KJS::ReferenceError);
}
@@ -136,12 +136,12 @@ KJS::Object QCanvasPixmapImp::construct( KJS::ExecState *exec, const KJS::List &
KJS::Object QCanvasPixmapImp::QCanvasPixmap_1( KJS::ExecState *exec, const KJS::List &args )
{
- QString arg0 = extractQString(exec, args, 0);
+ TQString arg0 = extractQString(exec, args, 0);
- // We should now create an instance of the QCanvasPixmap object
+ // We should now create an instance of the TQCanvasPixmap object
- QCanvasPixmap *ret = new QCanvasPixmap(
+ TQCanvasPixmap *ret = new TQCanvasPixmap(
arg0 );
@@ -151,12 +151,12 @@ KJS::Object QCanvasPixmapImp::QCanvasPixmap_1( KJS::ExecState *exec, const KJS::
KJS::Object QCanvasPixmapImp::QCanvasPixmap_2( KJS::ExecState *exec, const KJS::List &args )
{
- QImage arg0 = extractQImage(exec, args, 0);
+ TQImage arg0 = extractQImage(exec, args, 0);
- // We should now create an instance of the QCanvasPixmap object
+ // We should now create an instance of the TQCanvasPixmap object
- QCanvasPixmap *ret = new QCanvasPixmap(
+ TQCanvasPixmap *ret = new TQCanvasPixmap(
arg0 );
@@ -167,14 +167,14 @@ KJS::Object QCanvasPixmapImp::QCanvasPixmap_2( KJS::ExecState *exec, const KJS::
KJS::Object QCanvasPixmapImp::QCanvasPixmap_3( KJS::ExecState *exec, const KJS::List &args )
{
- QPixmap arg0 = extractQPixmap(exec, args, 0);
+ TQPixmap arg0 = extractQPixmap(exec, args, 0);
- QPoint arg1 = extractQPoint(exec, args, 1);
+ TQPoint arg1 = extractQPoint(exec, args, 1);
- // We should now create an instance of the QCanvasPixmap object
+ // We should now create an instance of the TQCanvasPixmap object
- QCanvasPixmap *ret = new QCanvasPixmap(
+ TQCanvasPixmap *ret = new TQCanvasPixmap(
arg0,
arg1 );
@@ -205,7 +205,7 @@ KJS::Value QCanvasPixmapImp::call( KJS::ExecState *exec, KJS::Object &self, cons
break;
}
- QString msg = i18n( "QCanvasPixmapImp has no method with id '%1'." ).arg( id );
+ TQString msg = i18n( "QCanvasPixmapImp has no method with id '%1'." ).arg( id );
return throwError(exec, msg,KJS::ReferenceError);
}
@@ -84,25 +84,25 @@ void QCanvasPixmapImp::addBindings( KJS::ExecState *exec, KJS::Object &object )
}
/**
- * Extract a QCanvasPixmap pointer from an Object.
+ * Extract a TQCanvasPixmap pointer from an Object.
*/